package com.game.business.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.game.business.domain.AppGameClassify;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author game
 * @date 2024-06-14
 */
public interface AppGameClassifyMapper extends BaseMapper<AppGameClassify> {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public AppGameClassify selectAppGameClassifyById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appGameClassify 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<AppGameClassify> selectAppGameClassifyList(AppGameClassify appGameClassify);

    /**
     * 新增【请填写功能名称】
     *
     * @param appGameClassify 【请填写功能名称】
     * @return 结果
     */
    public int insertAppGameClassify(AppGameClassify appGameClassify);

    /**
     * 修改【请填写功能名称】
     *
     * @param appGameClassify 【请填写功能名称】
     * @return 结果
     */
    public int updateAppGameClassify(AppGameClassify appGameClassify);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteAppGameClassifyById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppGameClassifyByIds(Long[] ids);
}